parse_doc_comment

Function parse_doc_comment 

pub fn parse_doc_comment(parts: &[String]) -> Option<DocComment>
Parse one or more raw comment strings (e.g. from multiple preceding trivia tokens). If the combined text contains a block comment (/** ... */), only that block is used so that a preceding line comment (e.g. // Comment) does not corrupt the doc block.