build_include_tree

Function build_include_tree 

pub fn build_include_tree(
    source: &str,
    base_path: Option<&Path>,
) -> Result<IncludeTree, IncludeError>
Build the include tree: parse source as the main file, resolve each include("path"), load and parse those files (with circular include detection), and return the tree.

If base_path is None (e.g. stdin), the current working directory is used to resolve includes.